@@ -1,15 +1,12 @@
-/***************************************************************************
- *   Copyright (C) 2004-2008 by Albert Astals Cid <aacid@kde.org>          *
- *   Copyright (C) 2004 by Enrico Ros <eros.kde@email.it>                  *
- *   Copyright (C) 2017    Klarälvdalens Datakonsult AB, a KDAB Group      *
- *                         company, info@kdab.com. Work sponsored by the   *
- *                         LiMux project of the city of Munich             *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2004-2008 Albert Astals Cid <aacid@kde.org>
+    SPDX-FileCopyrightText: 2004 Enrico Ros <eros.kde@email.it>
+
+    Work sponsored by the LiMux project of the city of Munich:
+    SPDX-FileCopyrightText: 2017 Klarälvdalens Datakonsult AB a KDAB Group company <info@kdab.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef _OKULAR_GENERATOR_PDF_H_
 #define _OKULAR_GENERATOR_PDF_H_
@@ -136,8 +133,11 @@ private:
     // poppler dependent stuff
     Poppler::Document *pdfdoc;
 
+    void xrefReconstructionHandler();
+
     // misc variables for document info and synopsis caching
     bool docSynopsisDirty;
+    bool xrefReconstructed;
     Okular::DocumentSynopsis docSyn;
     mutable bool docEmbeddedFilesDirty;
     mutable QList<Okular::EmbeddedFile *> docEmbeddedFiles;
