@@ -1,11 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2005 by Enrico Ros <eros.kde@email.it>                  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005 Enrico Ros <eros.kde@email.it>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "pagepainter.h"
 
@@ -35,7 +32,7 @@
 #include "settings.h"
 #include "settings_core.h"
 
-Q_GLOBAL_STATIC_WITH_ARGS(QPixmap, busyPixmap, (KIconLoader::global()->loadIcon(QLatin1String("okular"), KIconLoader::NoGroup, KIconLoader::SizeLarge, KIconLoader::DefaultState, QStringList(), nullptr, true)))
+Q_GLOBAL_STATIC_WITH_ARGS(QPixmap, busyPixmap, (QIcon::fromTheme(QLatin1String("okular")).pixmap(KIconLoader::SizeLarge)))
 
 #define TEXTANNOTATION_ICONSIZE 24
 
@@ -109,7 +106,7 @@ void PagePainter::paintCroppedPageOnPainter(QPainter *destPainter,
 
         if (p != nullptr) {
             pixmap = *p;
-            pixmap.setDevicePixelRatio(qApp->devicePixelRatio());
+            pixmap.setDevicePixelRatio(dpr);
         }
 
         /** 1B - IF NO PIXMAP, DRAW EMPTY PAGE **/
@@ -253,7 +250,7 @@ void PagePainter::paintCroppedPageOnPainter(QPainter *destPainter,
 
                 if (!limitsInTile.isEmpty()) {
                     QPixmap *tilePixmap = tile.pixmap();
-                    tilePixmap->setDevicePixelRatio(qApp->devicePixelRatio());
+                    tilePixmap->setDevicePixelRatio(dpr);
 
                     if (tilePixmap->width() == dTileRect.width() && tilePixmap->height() == dTileRect.height()) {
                         destPainter->drawPixmap(limitsInTile.topLeft(), *tilePixmap, dLimitsInTile.translated(-dTileRect.topLeft()));
@@ -293,7 +290,7 @@ void PagePainter::paintCroppedPageOnPainter(QPainter *destPainter,
 
                 if (!limitsInTile.isEmpty()) {
                     QPixmap *tilePixmap = tile.pixmap();
-                    tilePixmap->setDevicePixelRatio(qApp->devicePixelRatio());
+                    tilePixmap->setDevicePixelRatio(dpr);
 
                     if (tilePixmap->width() == dTileRect.width() && tilePixmap->height() == dTileRect.height()) {
                         p.drawPixmap(limitsInTile.translated(-limits.topLeft()).topLeft(), *tilePixmap, dLimitsInTile.translated(-dTileRect.topLeft()));
@@ -572,10 +569,7 @@ void PagePainter::paintCroppedPageOnPainter(QPainter *destPainter,
                     mixedPainter->drawImage(annotBoundary.topLeft(), image);
                 } else if (text->textType() == Okular::TextAnnotation::Linked) {
                     // get pixmap, colorize and alpha-blend it
-                    QString path;
-                    QPixmap pixmap = GuiUtils::iconLoader()->loadIcon(text->textIcon().toLower(), KIconLoader::User, 32, KIconLoader::DefaultState, QStringList(), &path, true);
-                    if (path.isEmpty())
-                        pixmap = GuiUtils::iconLoader()->loadIcon(text->textIcon().toLower(), KIconLoader::NoGroup, 32);
+                    QPixmap pixmap = QIcon::fromTheme(text->textIcon().toLower()).pixmap(32);
 
                     QPixmap scaledCroppedPixmap = pixmap.scaled(TEXTANNOTATION_ICONSIZE * dpr, TEXTANNOTATION_ICONSIZE * dpr).copy(dInnerRect.toAlignedRect());
                     scaledCroppedPixmap.setDevicePixelRatio(dpr);
