@@ -1,22 +1,18 @@
-/***************************************************************************
- *   Copyright (C) 2004 by Enrico Ros <eros.kde@email.it>                  *
- *   Copyright (C) 2004 by Albert Astals Cid <aacid@kde.org>               *
- *   Copyright (C) 2017    Klarälvdalens Datakonsult AB, a KDAB Group      *
- *                         company, info@kdab.com. Work sponsored by the   *
- *                         LiMux project of the city of Munich             *
- *                                                                         *
- *   With portions of code from kpdf/kpdf_pagewidget.h by:                 *
- *     Copyright (C) 2002 by Wilco Greven <greven@kde.org>                 *
- *     Copyright (C) 2003 by Christophe Devriese                           *
- *                           <Christophe.Devriese@student.kuleuven.ac.be>  *
- *     Copyright (C) 2003 by Laurent Montel <montel@kde.org>               *
- *     Copyright (C) 2003 by Kurt Pfeifle <kpfeifle@danka.de>              *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2004 Enrico Ros <eros.kde@email.it>
+    SPDX-FileCopyrightText: 2004 Albert Astals Cid <aacid@kde.org>
+
+    Work sponsored by the LiMux project of the city of Munich:
+    SPDX-FileCopyrightText: 2017 Klarälvdalens Datakonsult AB a KDAB Group company <info@kdab.com>
+
+    With portions of code from kpdf/kpdf_pagewidget.h by:
+    SPDX-FileCopyrightText: 2002 Wilco Greven <greven@kde.org>
+    SPDX-FileCopyrightText: 2003 Christophe Devriese <Christophe.Devriese@student.kuleuven.ac.be>
+    SPDX-FileCopyrightText: 2003 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2003 Kurt Pfeifle <kpfeifle@danka.de>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 // This file follows coding style described in kdebase/kicker/HACKING
 
 #ifndef _OKULAR_PAGEVIEW_H_
@@ -126,9 +122,6 @@ public Q_SLOTS:
     void openAnnotationWindow(Okular::Annotation *annotation, int pageNumber);
     void reloadForms();
 
-    void slotToggleChangeColors();
-    void slotSetChangeColors(bool active);
-
     void slotSelectPage();
 
     void slotAction(Okular::Action *action);
@@ -226,6 +219,13 @@ private:
     // Update speed of animated smooth scroll transitions
     void updateSmoothScrollAnimationSpeed();
 
+    /*
+     * returns the continuous mode value of the current document, by either:
+     * - if the continuous mode action is initialized, then we return its associated value
+     * - if not, then we will fallback to the default settings
+     */
+    bool getContinuousMode() const;
+
     // don't want to expose classes in here
     class PageViewPrivate *d;
 
@@ -259,10 +259,10 @@ private Q_SLOTS:
     void slotFitToPageToggled(bool);
     void slotAutoFitToggled(bool);
     void slotViewMode(QAction *action);
-    void slotContinuousToggled(bool);
+    void slotContinuousToggled();
     void slotReadingDirectionToggled(bool leftToRight);
     void slotUpdateReadingDirectionAction();
-    void slotMouseNormalToggled(bool);
+    void slotSetMouseNormal();
     void slotSetMouseZoom();
     void slotSetMouseMagnifier();
     void slotSetMouseSelect();
